import 'package:equatable/equatable.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get_it/get_it.dart';
import 'package:supper_app/src/services/storage_service/storage_service.dart';

enum AppTheme {
  light,
  dark,
}

enum AppLanguage { en, vi }

class AppState<T extends AppTheme, V extends AppLanguage> extends Equatable {
  const AppState({required this.appTheme, this.appLanguage});
  final T appTheme;
  final V? appLanguage;

  @override
  List<Object?> get props => <Object?>[appTheme, appLanguage];
}

class AppCubit extends Cubit<AppState<AppTheme, AppLanguage>> {
  AppCubit(AppState<AppTheme, AppLanguage> appState)
      : super(const AppState<AppTheme, AppLanguage>(
            appTheme: AppTheme.light, appLanguage: AppLanguage.en));

  Future<bool> saveLanguage(String langCode) {
    final StorageService storageService = GetIt.instance<StorageService>();
    return storageService.shared.setString('language', langCode);
  }

  Future<bool> saveTheme(String langCode) {
    final StorageService storageService = GetIt.instance<StorageService>();
    return storageService.shared.setString('theme', langCode);
  }

  void changeTheme({required AppTheme theme}) {
    saveTheme(theme.toString());
    emit(AppState<AppTheme, AppLanguage>(
        appTheme: theme, appLanguage: state.appLanguage));
  }

  void changeLanguage({required AppLanguage language}) {
    saveLanguage(language.toString());
    emit(AppState<AppTheme, AppLanguage>(
        appLanguage: language, appTheme: state.appTheme));
  }
}
